@@ -1,6 +1,6 @@
-/* Copyright (c) 2012-2014 LevelDOWN contributors
- * See list at <https://github.com/rvagg/node-leveldown#contributing>
- * MIT License <https://github.com/rvagg/node-leveldown/blob/master/LICENSE.md>
+/* Copyright (c) 2012-2015 LevelDOWN contributors
+ * See list at <https://github.com/level/leveldown#contributing>
+ * MIT License <https://github.com/level/leveldown/blob/master/LICENSE.md>
  */
 
 #ifndef LD_LEVELDOWN_ASYNC_H
@@ -15,29 +15,29 @@ namespace leveldown {
 class DestroyWorker : public AsyncWorker {
 public:
   DestroyWorker (
-      NanUtf8String* location
-    , NanCallback *callback
+      Nan::Utf8String* location
+    , Nan::Callback *callback
   );
 
   virtual ~DestroyWorker ();
   virtual void Execute ();
 
 private:
-  NanUtf8String* location;
+  Nan::Utf8String* location;
 };
 
 class RepairWorker : public AsyncWorker {
 public:
   RepairWorker (
-      NanUtf8String* location
-    , NanCallback *callback
+      Nan::Utf8String* location
+    , Nan::Callback *callback
   );
 
   virtual ~RepairWorker ();
   virtual void Execute ();
 
 private:
-  NanUtf8String* location;
+  Nan::Utf8String* location;
 };
 
 } // namespace leveldown
