@@ -1,7 +1,6 @@
-const test       = require('tap').test
+const test       = require('tape')
     , testCommon = require('abstract-leveldown/testCommon')
     , leveldown  = require('../')
     , abstract   = require('abstract-leveldown/abstract/approximate-size-test')
 
-if (require.main === module)
-  abstract.all(leveldown, test, testCommon)
\ No newline at end of file
+abstract.all(leveldown, test, testCommon)
