@@ -1,6 +1,5 @@
-const test      = require('tap').test
+const test      = require('tape')
     , leveldown = require('../')
     , abstract  = require('abstract-leveldown/abstract/leveldown-test')
 
-if (require.main === module)
-  abstract.args(leveldown, test)
\ No newline at end of file
+abstract.args(leveldown, test)
